<?php
/**
 * WP-Members Form Building Functions
 *
 * Handles functions that build the various forms.
 * 
 * This file is part of the WP-Members plugin by Chad Butler
 * You can find out more about this plugin at http://rocketgeek.com
 * Copyright (c) 2006-2014  Chad Butler
 * WP-Members(tm) is a trademark of butlerblog.com
 *
 * @package WordPress
 * @subpackage WP-Members
 * @author Chad Butler
 * @copyright 2006-2014
 *
 * Functions Included:
 * * wpmem_inc_login
 * * wpmem_inc_changepassword
 * * wpmem_inc_resetpassword
 * * wpmem_inc_registration
 * * wpmem_login_form
 * * wpmem_inc_recaptcha
 * * wpmem_inc_attribution
 */


if ( ! function_exists( 'wpmem_inc_login' ) ):
/**
 * Login Dialog
 *
 * Loads the login form for user login
 *
 * @since 1.8
 *
 * @uses apply_filters Calls 'wpmem_inc_login_args'
 * @uses apply_filters Calls wpmem_restricted_msg filter to change the restricted post message content
 * @uses wpmem_login_form()
 *
 * @param  string $page
 * @return string $str the generated html for the login form
 */
function wpmem_inc_login( $page="page" )
{ 	
	global $wpmem_regchk;

	$str = '';

	if( $page == "page" ){
	     if( $wpmem_regchk!="success" ){

			$arr = get_option( 'wpmembers_dialogs' );
			
			// this shown above blocked content
			$str = '<p>' . stripslashes($arr[0]) . '</p>';
			
			// filter blocked content message
			$str = apply_filters( 'wpmem_restricted_msg', $str );

		} 	
	} 

    $defaults = array( 
		'heading'      => __( 'Existing Users Log In', 'wp-members' ), 
		'input1'       => __( 'Username', 'wp-members' ), 
		'input1_type'  => 'text', 
		'input1_tag'   => 'log',
		'input2'       => __( 'Password', 'wp-members' ), 
		'input2_type'  => 'password', 
		'input2_tag'   => 'pwd', 
		'action'       => 'login', 
		'button_text'  => __( 'Log In', 'wp-members' ), 
		'input1_class' => 'username', 
		'input2_class' => 'password' 
	);
	
	$args = apply_filters( 'wpmem_inc_login_args', '' );

	$arr  = wp_parse_args( $args, $defaults );
	
	$str  = $str . wpmem_login_form( $page, $arr );
	
	return $str;
}
endif;


if ( ! function_exists( 'wpmem_inc_changepassword' ) ):
/**
 * Change Password Dialog
 *
 * Loads the form for changing password.
 *
 * @since 2.0
 *
 * @uses apply_filters Calls 'wpmem_inc_changepassword_args'
 * @uses wpmem_login_form()
 *
 * @return string $str the generated html for the change password form
 */
function wpmem_inc_changepassword()
{
	$defaults = array(
		'heading'      => __('Change Password', 'wp-members'), 
		'input1'       => __('New Password', 'wp-members'), 
		'input1_type'  => 'password', 
		'input1_tag'   => 'pass1', 
		'input2'       => __('Repeat Password', 'wp-members'), 
		'input2_type'  => 'password', 
		'input2_tag'   => 'pass2', 
		'action'       => 'pwdchange', 
		'button_text'  => __('Update Password', 'wp-members'), 
		'input1_class' => 'password', 
		'input2_class' => 'password'
	);

	$args = apply_filters( 'wpmem_inc_changepassword_args', '' );

	$arr  = wp_parse_args( $args, $defaults );

    $str  = wpmem_login_form( 'page', $arr );
	
	return $str;
}
endif;


if ( ! function_exists( 'wpmem_inc_resetpassword' ) ):
/**
 * Reset Password Dialog
 *
 * Loads the form for resetting password.
 *
 * @since 2.1
 *
 * @uses apply_filters Calls 'wpmem_inc_resetpassword_args'
 * @uses wpmem_login_form()
 *
 * @return string $str the generated html fo the reset password form
 */
function wpmem_inc_resetpassword()
{ 
	$defaults = array(
		'heading'      => __('Reset Forgotten Password', 'wp-members'), 
		'input1'       => __('Username', 'wp-members'), 
		'input1_type'  => 'text', 
		'input1_tag'   => 'user', 
		'input2'       => __('Email', 'wp-members'), 
		'input2_type'  => 'text', 
		'input2_tag'   => 'email', 
		'action'       => 'pwdreset', 
		'button_text'  => __('Reset Password', 'wp-members'), 
		'input1_class' => 'username', 
		'input2_class' => 'textbox'
	);

	$args = apply_filters( 'wpmem_inc_resetpassword_args', '' );

	$arr  = wp_parse_args( $args, $defaults );

    $str  = wpmem_login_form( 'page', $arr );
	
	return $str;
}
endif;


if ( ! function_exists( 'wpmem_inc_registration' ) ):
/**
 * Registration Form Dialog
 *
 * Outputs the form for new user registration and existing user edits.
 *
 * @since 2.5.1
 *
 * @uses apply_filters Calls 'wpmem_register_form_args' filters array of default tags, labels, and small items
 * @uses apply_filters Calls 'wpmem_register_form_row' filters the form field rows as the form is built before adding to the form
 * @uses apply_filters Calls 'wpmem_register_fields_arr' filters the fields array - THIS MAY CHANGE
 * @uses apply_filters Calls 'wpmem_tos_link_txt' filter to change the text (and link) for the TOS (Terms of Service) acknowledgement
 * @uses apply_filters Calls 'wpmem_register_captcha_row' filters the captcha row before it is added to the form
 * @uses apply_filters Calls 'wpmem_register_hidden_fields' filters the hidden fields before adding to the form
 * @uses apply_fitlers Calls 'wpmem_register_form_buttons' filters the buttons wrapper and inputs before adding to the form
 * @uses apply_filters Calls 'wpmem_register_heading' filter to change the heading of the registration form
 * @uses apply_filters Calls 'wpmem_register_form_before' filter to add any string to the beginning of the registration form
 * @uses apply_filters Calls 'wpmem_register_form' filter to change any element of the generated HTML string of the registration form
 *
 * @param  string $toggle       (optional) Toggles between new registration ('new') and user profile edit ('edit')
 * @param  string $heading      (optional) The heading text for the form, null (default) for new registration
 * @global string $wpmem_regchk Used to determine if the form is in an error state
 * @global array  $userdata     Used to get the user's registration data if they are logged in (user profile edit)
 * @return string $form         The HTML for the entire form as a string
 */
function wpmem_inc_registration( $toggle = 'new', $heading = '' )
{	
	global $wpmem_regchk, $userdata; 
	
	// set up default wrappers
	$defaults = array(
		
		// wrappers
		'heading_before'  => '<legend>',
		'heading_after'   => '</legend>',
		'fieldset_before' => '<fieldset>',
		'fieldset_after'  => '</fieldset>',
		'main_div_before' => '<div id="wpmem_reg">',
		'main_div_after'  => '</div>',
		'txt_before'      => '[wpmem_txt]',
		'txt_after'       => '[/wpmem_txt]',
		'row_before'      => '',
		'row_after'       => '',
		'buttons_before'  => '<div class="button_div">',
		'buttons_after'   => '</div>',
		
		// classes & ids
		'form_id'         => '',
		'form_class'      => 'form',
		'button_id'       => '',
		'button_class'    => 'buttons',
		
		// required field tags and text
		'req_mark'         => '<font class="req">*</font>',
		'req_label'        => __( 'Required field', 'wp-members' ),
		'req_label_before' => '<div class="req-text">',
		'req_label_after'  => '</div>',
		
		// buttons
		'show_clear_form'  => true,
		'clear_form'       => __( 'Reset Form', 'wp-members' ),
		'submit_register'  => __( 'Register', 'wp-members' ),
		'submit_update'    => __( 'Update Profile', 'wp-members' ),
		
		// other
		'strip_breaks'     => true,
		'use_nonce'        => false,
		'wrap_inputs'      => true,
		'n'                => "\n",
		't'                => "\t",
		
	);
	
	// filter $args
	$args = apply_filters( 'wpmem_register_form_args', '', $toggle );
	
	// merge $args with defaults and extract
	extract( wp_parse_args( $args, $defaults ) );
	
	// Username is editable if new reg, otherwise user profile is not
	if( $toggle == 'edit' ) {
		
		// this is the User Profile edit - username is not editable
		$val = $userdata->user_login;
		$row = '<label for="username" class="text">' . __( 'Username', 'wp-members' ) . '</label>' . $n;
		$input = '<p class="noinput">' . $val . '</p>' . $n;
		$row.= ( $wrap_inputs ) ? '<div class="div_text">' . $input . '</div>' . $n : $input . $n;

	} else { 

		// this is a new registration
		$val = ( isset( $_POST['log'] ) ) ? stripslashes( $_POST['log'] ) : '';
		$row = '<label for="username" class="text">' . __( 'Choose a Username', 'wp-members' ) . $req_mark . '</label>' . $n;
		$input = wpmem_create_formfield( 'log', 'text', $val, '', 'username' );
		$row.= ( $wrap_inputs ) ? '<div class="div_text">' . $n . $t . $input . $n . '</div>' . $n : $input . $n;
	
	}
	
	// filter the username row
	$row = apply_filters( 'wpmem_register_form_row', $row_before . $row . $row_after, 'username', 'text', $toggle );
	
	// add the username row to the array
	$rows[] = array( 'meta'=>'username', 'type'=>'text', 'val'=>$val, 'row'=>$row );
	
	// loop through the remaining fields
	//$wpmem_fields = get_option( 'wpmembers_fields' );
	$wpmem_fields = apply_filters( 'wpmem_register_fields_arr', get_option( 'wpmembers_fields' ), $toggle );
	
	foreach( $wpmem_fields as $field )
	{
		// start with a clean row
		$row = ''; $val = '';
		
		// skips user selected passwords for profile update
		$do_row = ( $toggle == 'edit' && $field[2] == 'password' ) ? false : true;
		
		// skips tos, makes tos field hidden on user edit page, unless they haven't got a value for tos
		if( $field[2] == 'tos' && $toggle == 'edit' && ( get_user_meta( $userdata->ID, 'tos', true ) ) ) { 
			$do_row = false; 
			$hidden_tos = wpmem_create_formfield( $field[2], 'hidden', get_user_meta( $userdata->ID, 'tos', true ) );
		}
		
		// if the field is set to display and we aren't skipping, construct the row
		if( $field[4] == 'y' && $do_row == true ) {

			// label for all but TOS
			if( $field[2] != 'tos' ) {

				$class = ( $field[3] == 'password' ) ? 'text' : $field[3];
				
				$row = $row . '<label for="' . $field[2] . '" class="' . $class . '">' . __( $field[1], 'wp-members' );
				$row = ( $field[5] == 'y' ) ? $row . $req_mark : $row;
				$row = $row . '</label>' . $n;

			} 

			// gets the field value for both edit profile and submitted reg w/ error
			if( ( $toggle == 'edit' ) && ( $wpmem_regchk != 'updaterr' ) ) { 

				switch( $field[2] ) {
					case( 'description' ):
						$val = htmlspecialchars( get_user_meta( $userdata->ID, 'description', 'true' ) );
						break;

					case( 'user_email' ):
						$val = $userdata->user_email;
						break;

					case( 'user_url' ):
						$val = esc_url( $userdata->user_url );
						break;

					default:
						$val = htmlspecialchars( get_user_meta( $userdata->ID, $field[2], 'true' ) );
						break;
				}

			} else {

				$val = ( isset( $_POST[ $field[2] ] ) ) ? $_POST[ $field[2] ] : '';

			}
			
			// does the tos field
			if( $field[2] == 'tos' ) {

				$val = ( isset( $_POST[ $field[2] ] ) ) ? $_POST[ $field[2] ] : ''; 

				// should be checked by default? and only if form hasn't been submitted
				$val = ( ! $_POST && $field[8] == 'y' ) ? $field[7] : $val;
				$row = wpmem_create_formfield( $field[2], $field[3], $field[7], $val );
				$row = ( $field[5] == 'y' ) ? $row . $n . $req_mark : $row . $n;

				// determine if TOS is a WP page or not...
				$tos_content = stripslashes( get_option( 'wpmembers_tos' ) );
				if( has_shortcode( $tos_content, 'wp-members' ) ) {

					// this will change to do_shortcode which requires adding "tos" attr to wpmem_shortcode.
					$link = do_shortcode( $tos_content );
					
					$tos_pop = '<a href="' . $link . '" target="_blank">';
				} else { 
					$tos_pop = "<a href=\"#\" onClick=\"window.open('" . WP_PLUGIN_URL . "/wp-members/wp-members-tos.php','mywindow');\">";
				}
				$row.= apply_filters( 'wpmem_tos_link_txt', sprintf( __( 'Please indicate that you agree to the %s TOS %s', 'wp-members' ), $tos_pop, '</a>' ), $toggle );
				
				// in previous versions, the div class would end up being the same as the row before.
				$row = ( $wrap_inputs ) ? '<div class="div_text">' . $row . '</div>' . $n : $row . $n;

			} else {

				// for checkboxes
				if( $field[3] == 'checkbox' ) { 
					$valtochk = $val;
					$val = $field[7]; 
					// if it should it be checked by default (& only if form not submitted), then override above...
					if( $field[8] == 'y' && ( ! $_POST && $toggle != 'edit' ) ) { $val = $valtochk = $field[7]; }
				}

				// for dropdown select
				if( $field[3] == 'select' ) {
					$valtochk = $val;
					$val = $field[7];
				}

				if( ! isset( $valtochk ) ) { $valtochk = ''; }
				
				// for all other input types
				$input = wpmem_create_formfield( $field[2], $field[3], $val, $valtochk );
				
				// put the div wrapper and input together
				$row.= ( $wrap_inputs ) ? '<div class="div_' . $class . '">' . $n . $t . $input . $n . '</div>' . $n : $input . $n;
			}

		}
		
		// filter the row
		$row = apply_filters( 'wpmem_register_form_row', $row_before . $row . $row_after, $field[2], $field[3], $toggle );
		
		// if the row is set to display, add the row to the form array
		if( $field[4] == 'y' ) {
			$rows[] = array( 'meta'=>$field[2], 'type'=>$field[3], 'val'=>$val, 'row'=> $row_before . $row . $row_after );
		}
	}

	// filter the rows array
	$rows = apply_filters( 'wpmem_register_form_rows', $rows, $toggle );
	
	// put the rows from the array into $form
	$form = '';
	foreach( $rows as $row_item ) {
		$form = $form . $row_item['row'];
	}
	
	// do captcha if enabled
	if( WPMEM_CAPTCHA == 1 && $toggle != 'edit' ) { // don't show on edit page!
		
		// get the captcha options
		$wpmem_captcha = get_option('wpmembers_captcha'); 
		
		// start with a clean row
		$row = '';
		
		if( $wpmem_captcha[0] && $wpmem_captcha[1] ) {
			$row = '<div class="clear"></div>';
			$row.= '<div align="right" class="captcha">' . wpmem_inc_recaptcha( $wpmem_captcha[0], $wpmem_captcha[2] ) . '</div>';
		} 
		
		// add the captcha row to the form
		$form.= apply_filters( 'wpmem_register_captcha_row', $row_before . $row . $row_after, $toggle );
	}

	// create hidden fields
	$var    = ( $toggle == 'edit' ) ? 'update' : 'register';
	$hidden = '<input name="a" type="hidden" value="' . $var . '" />' . $n;
	$hidden.= '<input name="redirect_to" type="hidden" value="' . get_permalink() . '" />' . $n;
	$hidden = ( isset( $hidden_tos ) ) ? $hidden . $hidden_tos . $n : $hidden;
	
	// add the hidden fields to the form
	$form.= apply_filters( 'wpmem_register_hidden_fields', $hidden, $toggle );
	
	// create buttons and wrapper
	$button_text = ( $toggle == 'edit' ) ? $submit_update : $submit_register;
	$buttons = ( $show_clear_form ) ? '<input name="reset" type="reset" value="' . $clear_form . '" class="' . $button_class . '" /> ' . $n : '';
	$buttons.= '<input name="submit" type="submit" value="' . $button_text . '" class="' . $button_class . '" />' . $n;
	
	// add the buttons to the form
	$form.= $buttons_before . $n . apply_filters( 'wpmem_register_form_buttons', $buttons, $toggle ) . $buttons_after . $n;

	// add the required field notation to the bottom of the form
	$form.= $req_label_before . $req_mark . $req_label . $req_label_after;
	
	// apply the heading
	$heading = ( !$heading ) ? apply_filters( 'wpmem_register_heading', __( 'New User Registration', 'wp-members' ), $toggle ) : $heading;
	$form = $heading_before . $heading . $heading_after . $n . $form;
	
	// apply fieldset wrapper
	$form = $fieldset_before . $n . $form . $n . $fieldset_after;
	
	// apply attribution if enabled
	$form = $form . wpmem_inc_attribution();
	
	// apply nonce
	$form = ( defined( 'WPMEM_USE_NONCE' ) || $use_nonce ) ? wp_nonce_field( 'wpmem-validate-submit', 'wpmem-form-submit' ) . $n . $form : $form;
	
	// apply form wrapper
	$form = '<form name="form" method="post" action="' . get_permalink() . '" id="' . $form_id . '" class="' . $form_class . '">' . $n . $form. $n . '</form>';
	
	// apply anchor
	$form = '<a name="register"></a>' . $n . $form;
	
	// apply main div wrapper
	$form = $main_div_before . $n . $form . $n . $main_div_after . $n;
	
	// apply wpmem_txt wrapper
	$form = $txt_before . $form . $txt_after;
	
	// remove line breaks if enabled for easier filtering later
	$form = ( $strip_breaks ) ? str_replace( array( "\n", "\r", "\t" ), array( '','','' ), $form ) : $form;
	
	// apply filters
	$form = apply_filters( 'wpmem_register_form', $form, $toggle );
	$form = apply_filters( 'wpmem_register_form_before', '', $toggle ) . $form;

	// return the generated form
	return $form;
} // end wpmem_inc_registration
endif;


if ( ! function_exists( 'wpmem_login_form' ) ):
/**
 * Login Form Dialog
 *
 * Builds the form used for login, change password, and reset password.
 *
 * @since 2.5.1
 *
 * @uses apply_filters Calls 'wpmem_login_form_args' filters the default tags and other elements
 * @uses apply_filters Calls 'wpmem_login_form_row' filters the current row as the form is being built
 * @uses apply_filters Calls 'wpmem_login_hidden_fields' filters the section of hidden fields
 * @uses apply_filters Calls 'wpmem_forgot_link' filter to change the link for resetting a forgotten password
 * @uses apply_filters Calls 'wpmem_forgot_link_str' NAME MAY CHANGE
 * @uses apply_filters Calls 'wpmem_reg_link' filter to change the link to the registration page
 * @uses apply_filters Calls 'wpmem_reg_link_str' NAME MAY CHANGE
 * @uses apply_filters Calls 'wpmem_login_form' filter to change any element in the generated string of HTML for the login form
 * @uses apply_filters Calls 'wpmem_login_form_before' filter to add any string to the beginning of the login form
 *
 * @param  string $page 
 * @param  array  $arr   The elements needed to generate the form (login|reset password|forgotten password)
 * @return string $form  The HTML for the form as a string
 */
function wpmem_login_form( $page, $arr ) 
{
	// set up default wrappers
	$defaults = array(
		
		// wrappers
		'heading_before'  => '<legend>',
		'heading_after'   => '</legend>',
		'fieldset_before' => '<fieldset>',
		'fieldset_after'  => '</fieldset>',
		'main_div_before' => '<div id="wpmem_login">',
		'main_div_after'  => '</div>',
		'txt_before'      => '[wpmem_txt]',
		'txt_after'       => '[/wpmem_txt]',
		'row_before'      => '',
		'row_after'       => '',
		'buttons_before'  => '<div class="button_div">',
		'buttons_after'   => '</div>',
		'link_before'     => '<div align="right">',
		'link_after'      => '</div>',
		
		// classes & ids
		'form_id'         => '',
		'form_class'      => 'form',
		'button_id'       => '',
		'button_class'    => 'buttons',
		
		// other
		'strip_breaks'     => true,
		'wrap_inputs'      => true,
		'num_inputs'       => 2,
		'n'                => "\n",
		't'                => "\t",
		
	);
	
	// filter $args
	$args = apply_filters( 'wpmem_login_form_args', '' );
	
	// merge $args with defaults and extract
	extract( wp_parse_args( $args, $defaults ) );

	// extract the array
	extract( $arr );
	
	// ROW 1
	$label = '<label for="' . $input1_tag . '">' . $input1 . '</label>' . $n;
	$input = wpmem_create_formfield( $input1_tag, $input1_type, '', '', $input1_class );
	$input = ( $wrap_inputs ) ? '<div class="div_text">' . $n . $t . $input . '</div>' . $n : $input;
	
	$form = apply_filters( 'wpmem_login_form_row', $row_before . $label . $input . $row_after, 1 );
	
	if( $num_inputs > 1 ) { 
		// ROW 2
		$label = '<label for="' . $input2_tag . '">' . $input2 . '</label>' . $n;
		$input = wpmem_create_formfield( $input2_tag, $input2_type, '', '', $input2_class );
		$input = ( $wrap_inputs ) ? '<div class="div_text">' . $n . $t . $input . '</div>' . $n : $input;
		
		$form.= apply_filters( 'wpmem_login_form_row', $row_before . $label . $input . $row_after );
	}
	
	// HIDDEN FIELDS
	$redirect_to = ( isset( $_REQUEST['redirect_to'] ) ) ? esc_url( $_REQUEST['redirect_to'] ) : get_permalink();

	$hidden = wpmem_create_formfield( 'redirect_to', 'hidden', $redirect_to );
	$hidden = $hidden . wpmem_create_formfield( 'a', 'hidden', $action );
	$hidden = ( $action != 'login' ) ? $hidden . wpmem_create_formfield( 'formsubmit', 'hidden', '1' ) : $hidden;
	$form   = $form . apply_filters( 'wpmem_login_hidden_fields', $hidden );

	// BUTTONS
	if ( $action == 'login' ) {
		$buttons = wpmem_create_formfield( 'rememberme', 'checkbox', 'forever' ) . '&nbsp;' . __('Remember me', 'wp-members') . '&nbsp;&nbsp;'
			. $n . $t . '<input type="submit" name="Submit" value="' . $button_text . '" class="' . $button_class . '" />' . $n;
	} else {
		$buttons = '<input type="submit" name="Submit" value="' . $button_text . '" class="' . $button_class . '" />' . $n;
	}
	
	$form = $form . $buttons_before . $n . $buttons . $buttons_after . $n;
	
//	$form = $form . '<div class="clear"></div>';

	if ( ( WPMEM_MSURL != null || $page == 'members' ) && $action == 'login' ) { 
		
		$link = apply_filters( 'wpmem_forgot_link', wpmem_chk_qstr( WPMEM_MSURL ) . 'a=pwdreset' );	
		$str  = __( 'Forgot password?', 'wp-members' ) . '&nbsp;<a href="' . $link . '">' . __( 'Click here to reset', 'wp-members' ) . '</a>';
		$form = $form . $link_before . apply_filters( 'wpmem_forgot_link_str', $str ) . $link_after . $n;
		
	}
	
	if ( ( WPMEM_REGURL != null ) && $action == 'login' ) { 

		$link = apply_filters( 'wpmem_reg_link', WPMEM_REGURL );
		$str  = __( 'New User?', 'wp-members' ) . '&nbsp;<a href="' . $link . '">' . __( 'Click here to register', 'wp-members' ) . '</a>';
		$form = $form . $link_before . apply_filters( 'wpmem_reg_link_str', $str ) . $link_after . $n;
		
	}			
	
//	$form = $form . '<div class="clear"></div>';
	
	// apply the heading
	$form = $heading_before . $heading . $heading_after . $n . $form;
	
	// apply fieldset wrapper
	$form = $fieldset_before . $n . $form . $fieldset_after . $n;
	
	// apply form wrapper
	$form = '<form action="' . get_permalink() . '" method="POST" id="' . $form_id . '" class="' . $form_class . '">' . $n . $form . '</form>';
	
	// apply anchor
	$form = '<a name="login"></a>' . $n . $form;
	
	// apply main wrapper
	$form = $main_div_before . $n . $form . $n . $main_div_after;
	
	// apply wpmem_txt wrapper
	$form = $txt_before . $form . $txt_after;
	
	// remove line breaks
	$form = ( $strip_breaks ) ? str_replace( array( "\n", "\r", "\t" ), array( '','','' ), $form ) : $form;
	
	// apply filters
	$form = apply_filters( 'wpmem_login_form', $form );
	$form = apply_filters( 'wpmem_login_form_before', '' ) . $form;
	
	return $form;
} // end wpmem_login_form
endif;


if ( ! function_exists( 'wpmem_inc_recaptcha' ) ):
/**
 * Create reCAPTCHA form
 *
 * @since  2.6.0
 *
 * @uses apply_filters Calls 'wpmem_recaptcha' filter to change the reCAPTCHA; used for implementing custom reCAPTCHA theme/layout
 *
 * @param  string $key
 * @param  string $theme
 * @return string $str
 */
function wpmem_inc_recaptcha( $key, $theme )
{
	$http = ( is_ssl() ) ? 'https://' : 'http://';
	$str  = '<script type="text/javascript">
			var RecaptchaOptions = { theme : \''. $theme . '\' };
		</script>
		<script type="text/javascript" src="' . $http . 'www.google.com/recaptcha/api/challenge?k=' . $key . '"></script>
		<noscript>
			<iframe src="' . $http . 'www.google.com/recaptcha/api/noscript?k=' . $key . '" height="300" width="500" frameborder="0"></iframe><br/>
			<textarea name="recaptcha_challenge_field" rows="3" cols="40"></textarea>
			<input type="hidden" name="recaptcha_response_field" value="manual_challenge"/>
		</noscript>';
		
	$str = apply_filters( 'wpmem_recaptcha', $str );
	
	return $str;
}
endif;


/**
 * Create an attribution link in the form
 *
 * @since 2.6.0
 * @return string $str
 */
function wpmem_inc_attribution()
{
	$http = ( is_ssl() ) ? 'https://' : 'http://';
	$str = '
	<div align="center">
		<small>Powered by <a href="' . $http . 'rocketgeek.com" target="_blank">WP-Members</a></small>
	</div>';
		
	return ( get_option( 'wpmembers_attrib' ) ) ? $str : '';
}

/** End of File **/